@@ -1,11 +1,12 @@
 
 .save_data <- function(new_data_digest,
-                       pkg_description,
+                       DataVersion,
                        object_names,
                        dataenv,
                        old_data_digest = NULL,
                        masterfile = NULL,
                        pkg_path = NULL) {
+  DataVersion <- validate_DataVersion(DataVersion)
   .save_digest(new_data_digest, path = pkg_path)
   .multilog_trace("Saving to data")
   # TODO get the names of each data object and save them separately. Provide a
@@ -17,7 +18,7 @@
   }
   # Update description file
   to_update <- desc::desc(file = file.path(pkg_path, "DESCRIPTION"))
-  to_update$set("DataVersion", pkg_description[["DataVersion"]])
+  to_update$set("DataVersion", DataVersion)
   to_update$set("Date", format(Sys.time(), "%Y-%m-%d"))
   to_update$write()
 }
